readBool method
Reads a boolean value from the source, and if not found, returns the
provided defaultValue.
Implementation
bool readBool(source, key, {bool defaultValue = false}) {
return tryReadBool(source, key) ?? defaultValue;
}
Reads a boolean value from the source, and if not found, returns the
provided defaultValue.
bool readBool(source, key, {bool defaultValue = false}) {
return tryReadBool(source, key) ?? defaultValue;
}