tryReadMap method
Tries to read a map value from the source. If the value is not a map,
it returns null.
Implementation
Map? tryReadMap(source, key) {
var value = readValue(source, key);
return isMap(value) ? value as Map : null;
}
Tries to read a map value from the source. If the value is not a map,
it returns null.
Map? tryReadMap(source, key) {
var value = readValue(source, key);
return isMap(value) ? value as Map : null;
}